# -*- coding: utf-8 -*-
from django.utils.translation import gettext_lazy as _
from rest_framework import viewsets
from rest_framework.decorators import action
from rest_framework.response import Response
from thx.api.mixins import ThuxModelMixin
from thx.role.core.views import ThuxRoleViewSetMixin

from ... import models
from . import serializers, filters, permissions

STATUS_CODES = ((0, _('disable')), (1, _('enable')),)


# VAT
class VatViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    """
    VatViewSet
    -----------

    :action list: Return the vat list.
        `Profiles`: `superuser`, `staff`

    :action retrieve: Return the given vat.
        `Profiles`: `superuser`, `staff`

    :action light: Return the vat list using light serialization.
        `Profiles`: `superuser`, `staff`

    :action create: Create a new vat instance.
        `Profiles`: `superuser`, `staff`

    :action update: Update a vat instance.
        `Profiles`: `superuser`, `staff`

    :action partial_update: Patch a vat instance.
        `Profiles`: `superuser`, `staff`

    :action destroy: Delete a vat instance.
        `Profiles`: `superuser`, `staff`
    """
    queryset = models.Vat.objects.all()
    serializer_class = serializers.VatSerializer

    filter_backends = (filters.VatFilterBackend,)
    permission_classes = (permissions.VatPermission,)

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        """
        Enable a vat instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        """
        Disable a vat instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path="status-choices")
    def status_choices(self, request, *args, **kwargs):
        """
        Return the status choices options.
        `Profiles`: `superuser`, `staff`
        """
        return Response(STATUS_CODES)
